Skip to main contentModule common
Source - Key
- A reference to an Open Library resource, e.g.
{ "key": "/works/OL45804W" }. - Link
- A hyperlink with a URL and optional title.
- PaginationLinks
- Pagination links returned in some list-style responses.
- TypedKey
- A typed reference that also carries the object type name.
- BooksJsCmd
jscmd parameter for the /api/books endpoint.- ChangeKind
- Kind of change in the Recent Changes API.
- CoverKey
- The key type used when querying covers.
- ImageSize
- Cover / photo image sizes.
- IntOrValue
- An integer that Open Library sometimes wraps as
{ "value": 123 }. - ReadingShelf
- Reading shelf identifier.
- SortOrder
- Sort order for search.
- TextOrValue
- A value that Open Library sometimes returns as a plain string and sometimes as
{ "value": "..." }. Use TextOrValue::into_text() to normalise. - VolumeIdType
- Identifier type used by the Partner (Volumes) API.